<input id="{{ name }}-input" data-initialized="false" data-map="input" class="controls map-input" type="text" placeholder="Search Box">
<div id="{{ name }}" data-initialized="false" data-map="map" class="map" {% if latitude %} data-latitude="{{latitude}}" {% endif %} {% if longitude %} data-longitude="{{longitude}}" {% endif %}></div>